==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Map.pm <==
package WebGUI::i18n::Dutch::Asset_Map;
use utf8;
our $I18N = {
  'add point label' => {
    'lastUpdated' => '1246969841',
    'message' => 'Voeg locatie toe'
  },
  'assetName' => {
    'lastUpdated' => '1246969808',
    'message' => 'Kaart'
  },
  'error add unauthorized' => {
    'lastUpdated' => '1246969869',
    'message' => 'U mag geen locaties toevoegen.'
  },
  'error delete unauthorized' => {
    'lastUpdated' => '1246969902',
    'message' => 'U mag deze locatie niet verwijderen.'
  },
  'error edit unauthorized' => {
    'lastUpdated' => '1246969924',
    'message' => 'U mag deze locatie niet bewerken.'
  },
  'error set center unauthorized' => {
    'lastUpdated' => '1246970352',
    'message' => 'U kunt niet instellen welk deel van de kaart standaard getoond wordt.'
  },
  'groupIdAddPoint description' => {
    'lastUpdated' => '1248781554',
    'message' => 'Groep die locaties aan de kaart mag toevoegen'
  },
  'groupIdAddPoint label' => {
    'lastUpdated' => '1248781585',
    'message' => 'Groep voor toevoegen van lokaties'
  },
  'mapApiKey description' => {
    'lastUpdated' => '1248781623',
    'message' => 'De door Google gegenereerde API code (key) voor deze website'
  },
  'mapApiKey label' => {
    'lastUpdated' => '1248781639',
    'message' => 'Google Maps API Key'
  },
  'mapApiKey link' => {
    'lastUpdated' => '1248781701',
    'message' => 'Vraag een Google Maps API key aan'
  },
  'mapHeight description' => {
    'lastUpdated' => '1248781899',
    'message' => 'De hoogte van de gegenereerde kaart. Vergeet niet om de eenheid in te vullen (px = pixels of % = procent).'
  },
  'mapHeight label' => {
    'lastUpdated' => '1248098672',
    'message' => 'Hoogte kaart'
  },
  'mapWidth description' => {
    'lastUpdated' => '1248781956',
    'message' => 'De breedte van de gegenereerde kaart. Vergeet niet om de eenheid in te vullen (px = pixels of % = procent).'
  },
  'mapWidth label' => {
    'lastUpdated' => '1248098655',
    'message' => 'Breedte kaart'
  },
  'message delete success' => {
    'lastUpdated' => '1248098690',
    'message' => 'Punt verwijderd'
  },
  'message set center success' => {
    'lastUpdated' => '1248098718',
    'message' => 'Standaard gebied instellen voltooid'
  },
  'message set point location' => {
    'lastUpdated' => '1248781985',
    'message' => 'Lokatie opgeslagen'
  },
  'select a point' => {
    'lastUpdated' => '1257329950',
    'message' => 'Selecteer een punt'
  },
  'set default viewing area label' => {
    'lastUpdated' => '1248782024',
    'message' => 'Definieer standaard bekijk gebied'
  },
  'startLatitude description' => {
    'lastUpdated' => '1248782055',
    'message' => 'Latitude van het standaard start punt van de kaart.'
  },
  'startLatitude label' => {
    'lastUpdated' => '1248782078',
    'message' => 'Start Latitude'
  },
  'startLongitude description' => {
    'lastUpdated' => '1248782114',
    'message' => 'Longitude van het standaard start punt van de kaart'
  },
  'startLongitude label' => {
    'lastUpdated' => '1248782129',
    'message' => 'Start Longitude'
  },
  'startZoom description' => {
    'lastUpdated' => '1248782162',
    'message' => 'Zoom eenheid van het standaard start punt van de kaart'
  },
  'startZoom label' => {
    'lastUpdated' => '1248782175',
    'message' => 'Start Zoom eenheid'
  },
  'templateIdEditPoint description' => {
    'lastUpdated' => '1248782216',
    'message' => 'Sjabloon voor het aanpassen van een kaart lokatie. Dit wordt vertoond binnen de kaart.'
  },
  'templateIdEditPoint label' => {
    'lastUpdated' => '1248782236',
    'message' => 'Sjabloon voor het aanpassen van een lokatie'
  },
  'templateIdView description' => {
    'lastUpdated' => '1248782260',
    'message' => 'Sjabloon voor het bekijken van de kaart.'
  },
  'templateIdView label' => {
    'lastUpdated' => '1248782278',
    'message' => 'Sjabloon voor het bekijken van de kaart'
  },
  'templateIdViewPoint description' => {
    'lastUpdated' => '1248782309',
    'message' => 'Sjabloon voor het bekijken van een lokatie. Dit wordt vertoond op een kaart.'
  },
  'templateIdViewPoint label' => {
    'lastUpdated' => '1248782331',
    'message' => 'Sjabloon voor het bekijken van een lokatie'
  },
  'workflowIdPoint description' => {
    'lastUpdated' => '1248782404',
    'message' => 'De workflow die uitgevoerd moet worden op het moment dat een lokatie is toegevoegd of aangepast.'
  },
  'workflowIdPoint label' => {
    'lastUpdated' => '1248782432',
    'message' => 'Workflow voor het toevoegen van lokaties'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Map.pm <==
package WebGUI::i18n::Dutch::Asset_Map;
use utf8;
our $I18N = {
  'add point label' => {
    'lastUpdated' => '1246969841',
    'message' => 'Voeg locatie toe'
  },
  'assetName' => {
    'lastUpdated' => '1246969808',
    'message' => 'Kaart'
  },
  'button_addPoint' => {
    'lastUpdated' => '1304607800',
    'message' => 'Een knop met een label voor het toevoegen van een knop.'
  },
  'button_setCenter' => {
    'lastUpdated' => '1304607836',
    'message' => 'Een knop die de kaart weer centraliseerd op de standaard waarde.'
  },
  'canAddPoint' => {
    'lastUpdated' => '1304607867',
    'message' => 'Een functie die waar is als de huidige gebruiker een nieuwe locatie aan de kaart kan toevoegen.'
  },
  'canEdit' => {
    'lastUpdated' => '1304607883',
    'message' => 'Een functie die waar is als de huidige gebruiker de kaart kan bewerken.'
  },
  'error add unauthorized' => {
    'lastUpdated' => '1246969869',
    'message' => 'U mag geen locaties toevoegen.'
  },
  'error delete unauthorized' => {
    'lastUpdated' => '1246969902',
    'message' => 'U mag deze locatie niet verwijderen.'
  },
  'error edit unauthorized' => {
    'lastUpdated' => '1246969924',
    'message' => 'U mag deze locatie niet bewerken.'
  },
  'error set center unauthorized' => {
    'lastUpdated' => '1246970352',
    'message' => 'U kunt niet instellen welk deel van de kaart standaard getoond wordt.'
  },
  'groupIdAddPoint' => {
    'lastUpdated' => '1304607723',
    'message' => 'De GUID van de groep die locaties aan de kaart kan toevoegen.'
  },
  'groupIdAddPoint description' => {
    'lastUpdated' => '1248781554',
    'message' => 'Groep die locaties aan de kaart mag toevoegen'
  },
  'groupIdAddPoint label' => {
    'lastUpdated' => '1248781585',
    'message' => 'Groep voor toevoegen van lokaties'
  },
  'map asset template variables' => {
    'lastUpdated' => '1304607899',
    'message' => 'Kaart sjabloonvariabelen'
  },
  'mapApiKey' => {
    'lastUpdated' => '1304607693',
    'message' => 'De Google Maps API key'
  },
  'mapApiKey description' => {
    'lastUpdated' => '1248781623',
    'message' => 'De door Google gegenereerde API code (key) voor deze website'
  },
  'mapApiKey label' => {
    'lastUpdated' => '1248781639',
    'message' => 'Google Maps API Key'
  },
  'mapApiKey link' => {
    'lastUpdated' => '1248781701',
    'message' => 'Vraag een Google Maps API key aan'
  },
  'mapHeight' => {
    'lastUpdated' => '1304607568',
    'message' => 'De hoogte van de kaart in pixels.'
  },
  'mapHeight description' => {
    'lastUpdated' => '1248781899',
    'message' => 'De hoogte van de gegenereerde kaart. Vergeet niet om de eenheid in te vullen (px = pixels of % = procent).'
  },
  'mapHeight label' => {
    'lastUpdated' => '1248098672',
    'message' => 'Hoogte kaart'
  },
  'mapPoints' => {
    'lastUpdated' => '1304607676',
    'message' => 'Een functie met punten op de kaart. Zie de Kaartlocatie sjabloonvariabelen voor de mogelijkheden.'
  },
  'mapWidth' => {
    'lastUpdated' => '1304607555',
    'message' => 'De breedte van de kaart in pixels.'
  },
  'mapWidth description' => {
    'lastUpdated' => '1248781956',
    'message' => 'De breedte van de gegenereerde kaart. Vergeet niet om de eenheid in te vullen (px = pixels of % = procent).'
  },
  'mapWidth label' => {
    'lastUpdated' => '1248098655',
    'message' => 'Breedte kaart'
  },
  'message delete success' => {
    'lastUpdated' => '1248098690',
    'message' => 'Punt verwijderd'
  },
  'message set center success' => {
    'lastUpdated' => '1248098718',
    'message' => 'Standaard gebied instellen voltooid'
  },
  'message set point location' => {
    'lastUpdated' => '1248781985',
    'message' => 'Lokatie opgeslagen'
  },
  'select a point' => {
    'lastUpdated' => '1257329950',
    'message' => 'Selecteer een punt'
  },
  'selectPoint' => {
    'lastUpdated' => '1304607536',
    'message' => 'Een dropdown menu zodat de kaart gecentreerd kan worden op een punt, en de informatie over het punt weergegeven kan worden.'
  },
  'set default viewing area label' => {
    'lastUpdated' => '1248782024',
    'message' => 'Definieer standaard bekijk gebied'
  },
  'startLatitude' => {
    'lastUpdated' => '1304607459',
    'message' => 'De breedtegraad waar de kaart in het begin gecentreerd is.'
  },
  'startLatitude description' => {
    'lastUpdated' => '1248782055',
    'message' => 'Latitude van het standaard start punt van de kaart.'
  },
  'startLatitude label' => {
    'lastUpdated' => '1248782078',
    'message' => 'Start Latitude'
  },
  'startLongitude' => {
    'lastUpdated' => '1304607488',
    'message' => 'De lengtegraad waar de kaart in het begin gecentreerd is.'
  },
  'startLongitude description' => {
    'lastUpdated' => '1248782114',
    'message' => 'Longitude van het standaard start punt van de kaart'
  },
  'startLongitude label' => {
    'lastUpdated' => '1248782129',
    'message' => 'Start Longitude'
  },
  'startZoom' => {
    'lastUpdated' => '1304607349',
    'message' => 'Het begin niveau voor de schaal van de kaart.'
  },
  'startZoom description' => {
    'lastUpdated' => '1248782162',
    'message' => 'Zoom eenheid van het standaard start punt van de kaart'
  },
  'startZoom label' => {
    'lastUpdated' => '1248782175',
    'message' => 'Start Zoom eenheid'
  },
  'templateIdEditPoint' => {
    'lastUpdated' => '1305868348',
    'message' => 'De GUID van het sjabloon voor het toevoegen en bewerken van een locatie.'
  },
  'templateIdEditPoint description' => {
    'lastUpdated' => '1248782216',
    'message' => 'Sjabloon voor het aanpassen van een kaart lokatie. Dit wordt vertoond binnen de kaart.'
  },
  'templateIdEditPoint label' => {
    'lastUpdated' => '1248782236',
    'message' => 'Sjabloon voor het aanpassen van een lokatie'
  },
  'templateIdView' => {
    'lastUpdated' => '1304608077',
    'message' => 'De GUID van het sjabloon voor het bekijken van de kaart.'
  },
  'templateIdView description' => {
    'lastUpdated' => '1248782260',
    'message' => 'Sjabloon voor het bekijken van de kaart.'
  },
  'templateIdView label' => {
    'lastUpdated' => '1248782278',
    'message' => 'Sjabloon voor het bekijken van de kaart'
  },
  'templateIdViewPoint' => {
    'lastUpdated' => '1304608097',
    'message' => 'De GUID van het sjabloon voor het bekijken van een locatie op de kaart.'
  },
  'templateIdViewPoint description' => {
    'lastUpdated' => '1248782309',
    'message' => 'Sjabloon voor het bekijken van een lokatie. Dit wordt vertoond op een kaart.'
  },
  'templateIdViewPoint label' => {
    'lastUpdated' => '1248782331',
    'message' => 'Sjabloon voor het bekijken van een lokatie'
  },
  'view template' => {
    'lastUpdated' => '1304607004',
    'message' => 'Kaart sjabloon'
  },
  'workflowIdPoint' => {
    'lastUpdated' => '1304607325',
    'message' => 'De GUID van de workflow voor het toevoegen van een punt op de kaart.'
  },
  'workflowIdPoint description' => {
    'lastUpdated' => '1248782404',
    'message' => 'De workflow die uitgevoerd moet worden op het moment dat een lokatie is toegevoegd of aangepast.'
  },
  'workflowIdPoint label' => {
    'lastUpdated' => '1248782432',
    'message' => 'Workflow voor het toevoegen van lokaties'
  }
}
;

1;
